@@ -16,16 +16,18 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with datamatrix.  If not, see <http://www.gnu.org/licenses/>.
 """
-
 from datamatrix.py3compat import *
 import datamatrix.monkeypatch
+from datamatrix._config import cfg
 from datamatrix._datamatrix._row import Row
 from datamatrix._datamatrix._mixedcolumn import MixedColumn
 from datamatrix._datamatrix._numericcolumn import FloatColumn, IntColumn
 from datamatrix._datamatrix._seriescolumn import SeriesColumn
+from datamatrix._datamatrix._multidimensionalcolumn import \
+    MultiDimensionalColumn
 from datamatrix._datamatrix._nifticolumn import NiftiColumn
 from datamatrix._datamatrix._datamatrix import DataMatrix
 
-__version__ = '0.15.3'
+__version__ = '1.0.0'
 NAN = float('nan')
 INF = float('inf')
